@@ -3,11 +3,23 @@ import scipy.special
 
 import matplotlib.pyplot as plt
 
+import igor_tools
+
+### ------------------------------------------------------------------------------
+### PUBLIC TOOLS
+### ------------------------------------------------------------------------------
+
+def create_itx(data, extent, wavename, filename):
+    dx = (extent[1] - extent[0]) / data.shape[0]
+    dy = (extent[3] - extent[2]) / data.shape[1]
+    xaxis = (extent[0], dx, "[ang]")
+    yaxis = (extent[2], dy, "[ang]")
+    igor_tools.write_2d_itx(filename, data, xaxis, yaxis, wavename)
+
 ### ------------------------------------------------------------------------------
 ### GEOMETRY TOOLS
 ### ------------------------------------------------------------------------------
 
-
 def scale_atoms(atoms, factor):
     cell_defined = True
     if atoms.cell is None or (atoms.cell == 0.0).all():
@@ -150,7 +162,7 @@ def visualize_evec(ax, atoms, evec):
     #print(" Vol: %.6f"%vol)
 
 
-def make_plot(ax, atoms, neighbor_list, data, title=None, filename=None):
+def make_evec_plot(ax, atoms, neighbor_list, data, title=None, filename=None):
 
     ax.set_aspect('equal')
     visualize_backbone(ax, atoms, neighbor_list)
